<script>
import AppLayout from "@/Layouts/AppLayout.vue";
import {MasterMethods} from "@/Store/Functions.js";
import ChartHome from "@/Pages/Explorer/ChartHome.vue";

export default {
    name: "Dashboard",
    components: {ChartHome, AppLayout},
    data(){
        return {
            clouds: [],
            level: this.$page.props.auth.user.role.name
        }
    },
    methods: {
        ...MasterMethods,
        formatClouds(){
            let categories = this.$page.props?.categories
            if(categories?.length > 0){
                categories.forEach(category => {
                    let clouds = category.clouds
                    if (clouds?.length > 0){
                        clouds.forEach(cloud => {
                            this.clouds.push(cloud)
                        })
                    }
                })
            }
        }
    },
    created() {
        this.formatClouds();
    }
}
</script>

<template>
    <AppLayout title="Dashboard">
        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight">
                Dashboard
            </h2>
        </template>

        <div class="pt-0">
            <div class="max-w-7xl mx-auto sm:px-6 lg:px-8">
                <div class="bg-white overflow-hidden shadow-xl sm:rounded-lg mb-4">
                    <div class="row">
                        <div class="col-sm-3 col-6">
                            <div class="description-block border-right">
                                <span class="description-percentage">
                                    <i v-if="level === 'VIP'" class="fa fa-diamond text-success"></i>
                                    <i v-if="level === 'Free'" class="fa fa-meh-o text-danger"></i>
                                    <i v-if="level === 'Admin'" class="fa fa-rocket text-info"></i>
                                </span>
                                <h5 class="description-header">Membresia</h5>
                                <span class="description-text">{{ level }}</span>
                            </div>
                            <!-- /.description-block -->
                        </div>

                        <div class="col-sm-2 col-6">
                            <div class="description-block border-right">
                                <span class="description-percentage text-info"><i class="fa fa-calendar"></i></span>
                                <h5 class="description-header">
                                    <span v-if="$page.props.auth?.user?.role_id != 2">NUNCA</span>
                                    <span v-else>{{$page.props.auth?.user?.vip_end_date}}</span>
                                </h5>
                                <span class="description-text">expira</span>
                            </div>
                            <!-- /.description-block -->
                        </div>

                        <!-- /.col -->
                        <div class="col-sm-3 col-6">
                            <div class="description-block border-right">
                                <span class="description-percentage text-warning"><i class="fa fa-cloud"></i></span>
                                <h5 class="description-header">{{ clouds.length }}</h5>
                                <span class="description-text">SharePoints</span>
                            </div>
                            <!-- /.description-block -->
                        </div>
                        <!-- /.col -->
                        <div class="col-sm-2 col-6">
                            <div class="description-block border-right">
                                <span class="description-percentage text-success"><i class="fa fa-caret-down"></i> {{ $page.props.downloadPercentage }}%</span>
                                <h5 class="description-header">{{ formatBytes($page.props.downloadSizeToday) }}</h5>
                                <span class="description-text">DESCARGADO</span>
                            </div>
                            <!-- /.description-block -->
                        </div>
                        <!-- /.col -->
                        <div class="col-sm-2 col-6">
                            <div class="description-block">
                                <span class="description-percentage text-danger"><i class="fa fa-caret-up"></i> {{$page.props.remainingPercentage }}%</span>
                                <h5 class="description-header">{{ formatBytes($page.props.remainingSize) }}</h5>
                                <span class="description-text">RESTANTE</span>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="row">
                    <div class="col-sm-12 col-md-5">
                        <div class="card">
                            <div class="card-header">
                                <h3 class="card-title">Tus descargas recientes</h3>
                            </div>
                            <!-- /.card-header -->
                            <div class="card-body p-0">
                                <ul class="products-list product-list-in-card pl-2 pr-2">
                                    <li class="item" v-for="item in $page.props?.downloadsToday">
                                        <div class="product-img">
                                            <img :src="'https://ui-avatars.com/api/?name='+item.name.replace('[GDADICTOS.COM] ','')+'&color=FFFFFF&background=0e0e0e'" alt="Product Image" class="img-size-50">
                                        </div>
                                        <div class="product-info">
                                            <a class="product-title">{{item.name}}
                                                <span class="badge badge-warning float-right">{{ formatBytes(item.size) }}</span></a>
                                            <span class="product-description">{{ item.downloaded_at}}</span>
                                        </div>
                                    </li>
                                </ul>
                            </div>
                        </div>
                    </div>
                    <ChartHome />
                </div>
            </div>
        </div>

    </AppLayout>
</template>

<style scoped>

</style>
